# orbital-transfer
Orbital transfer API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.6
- Package version: 0.0.6
- Generator version: 7.7.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import orbital_transfer
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import orbital_transfer
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import orbital_transfer
from orbital_transfer.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://orbital-transfer.exoops.57.128.40.142.sslip.io
# See configuration.py for a list of all supported configuration parameters.
configuration = orbital_transfer.Configuration(
    host = "http://orbital-transfer.exoops.57.128.40.142.sslip.io"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerAuth
configuration = orbital_transfer.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with orbital_transfer.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = orbital_transfer.DefaultApi(api_client)
    analytical_orbital_transfer_request = orbital_transfer.AnalyticalOrbitalTransferRequest() # AnalyticalOrbitalTransferRequest | 

    try:
        # compute analytical orbital transfer
        api_response = api_instance.compute_analytical_orbital_transfer(analytical_orbital_transfer_request)
        print("The response of DefaultApi->compute_analytical_orbital_transfer:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->compute_analytical_orbital_transfer: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://orbital-transfer.exoops.57.128.40.142.sslip.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**compute_analytical_orbital_transfer**](docs/DefaultApi.md#compute_analytical_orbital_transfer) | **POST** /orbitaltransfer/analytical | compute analytical orbital transfer
*DefaultApi* | [**compute_numerical_orbital_transfer**](docs/DefaultApi.md#compute_numerical_orbital_transfer) | **POST** /orbitaltransfer/numerical | compute numerical orbital transfer


## Documentation For Models

 - [AdvancedOrbitParameters](docs/AdvancedOrbitParameters.md)
 - [AnalyticalOrbitalTransferRequest](docs/AnalyticalOrbitalTransferRequest.md)
 - [AnalyticalOrbitalTransferResult](docs/AnalyticalOrbitalTransferResult.md)
 - [AngularCoordinates](docs/AngularCoordinates.md)
 - [BoundedEphemeris](docs/BoundedEphemeris.md)
 - [CircularAltitudeOrbitParameters](docs/CircularAltitudeOrbitParameters.md)
 - [CircularGroundTrackRepeatedOrbitParameters](docs/CircularGroundTrackRepeatedOrbitParameters.md)
 - [DoubleArrayDictionary](docs/DoubleArrayDictionary.md)
 - [DoubleArrayDictionaryDataInner](docs/DoubleArrayDictionaryDataInner.md)
 - [EllipticalGroundTrackRepeatedEccentricityOrbitParameters](docs/EllipticalGroundTrackRepeatedEccentricityOrbitParameters.md)
 - [EllipticalPerigeeAltApogeeAltOrbitParameters](docs/EllipticalPerigeeAltApogeeAltOrbitParameters.md)
 - [EllipticalPerigeeAltEccentricityOrbitParameters](docs/EllipticalPerigeeAltEccentricityOrbitParameters.md)
 - [EllipticalSmaEccentricityOrbitParameters](docs/EllipticalSmaEccentricityOrbitParameters.md)
 - [Frame](docs/Frame.md)
 - [NumericalOrbitalTransferRequest](docs/NumericalOrbitalTransferRequest.md)
 - [NumericalOrbitalTransferResult](docs/NumericalOrbitalTransferResult.md)
 - [NumericalOrbitalTransferResultFieldIndexesInner](docs/NumericalOrbitalTransferResultFieldIndexesInner.md)
 - [Orbit](docs/Orbit.md)
 - [OrbitOrekitParameters](docs/OrbitOrekitParameters.md)
 - [OrbitParameters](docs/OrbitParameters.md)
 - [ParametricPropulsionSystem](docs/ParametricPropulsionSystem.md)
 - [ParametricSpacecraft](docs/ParametricSpacecraft.md)
 - [PropulsionSystem](docs/PropulsionSystem.md)
 - [Rotation](docs/Rotation.md)
 - [Spacecraft](docs/Spacecraft.md)
 - [SpacecraftGeometry](docs/SpacecraftGeometry.md)
 - [SpacecraftState](docs/SpacecraftState.md)
 - [TimeStampedPVCoordinates](docs/TimeStampedPVCoordinates.md)
 - [Vector3D](docs/Vector3D.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication


## Author




